@@ -98,6 +98,16 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         return $query->getSelectQuery()->query();
     }
 
+    /**
+     * Get the connection configuration
+     *
+     * @return  ConfigObject
+     */
+    public function getConfig()
+    {
+        return $this->config;
+    }
+
     /**
      * Getter for database type
      *
@@ -131,7 +141,6 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
             'password'          => $this->config->password,
             'dbname'            => $this->config->dbname,
             'charset'           => $this->config->charset ?: null,
-            'persistent'        => (bool) $this->config->get('persistent', false),
             'options'           => & $genericAdapterOptions,
             'driver_options'    => & $driverOptions
         );
@@ -139,14 +148,22 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         switch ($this->dbType) {
             case 'mssql':
                 $adapter = 'Pdo_Mssql';
-                $pdoType = $this->config->get('pdoType', 'dblib');
+                $pdoType = $this->config->get('pdoType');
+                if (empty($pdoType)) {
+                    if (extension_loaded('sqlsrv')) {
+                        $adapter = 'Sqlsrv';
+                    } else {
+                        $pdoType = 'dblib';
+                    }
+                }
                 if ($pdoType === 'dblib') {
                     // Driver does not support setting attributes
-                    unset($adapterParamaters['persistent']);
                     unset($adapterParamaters['options']);
                     unset($adapterParamaters['driver_options']);
                 }
-                $adapterParamaters['pdoType'] = $pdoType;
+                if (! empty($pdoType)) {
+                    $adapterParamaters['pdoType'] = $pdoType;
+                }
                 $defaultPort = 1433;
                 break;
             case 'mysql':
@@ -207,6 +224,10 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                 $adapter = 'Pdo_Ibm';
                 $defaultPort = 50000;
                 break;
+            case 'sqlite':
+                $adapter = 'Pdo_Sqlite';
+                $defaultPort = 0; // Dummy port because a value is required
+                break;
             default:
                 throw new ConfigurationError(
                     'Backend "%s" is not supported',
