@@ -221,9 +221,9 @@ class DbTool
      */
     public function connect($dbname = null)
     {
-        $this->_pdoConnect($dbname);
+        $this->pdoConnect($dbname);
         if ($dbname !== null) {
-            $this->_zendConnect($dbname);
+            $this->zendConnect($dbname);
             $this->dbFromConfig = $dbname === $this->config['dbname'];
         }
     }
@@ -247,7 +247,7 @@ class DbTool
      *
      * @throws  ConfigurationError  In case the resource type is not a supported PDO driver name
      */
-    protected function _zendConnect($dbname)
+    private function zendConnect($dbname)
     {
         if ($this->zendConn !== null) {
             return;
@@ -262,6 +262,25 @@ class DbTool
         );
 
         if ($this->config['db'] === 'mysql') {
+            if (isset($this->config['use_ssl']) && $this->config['use_ssl']) {
+                $this->config['driver_options'] = array();
+                # The presence of these keys as empty strings or null cause non-ssl connections to fail
+                if ($this->config['ssl_key']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_KEY] = $this->config['ssl_key'];
+                }
+                if ($this->config['ssl_cert']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CERT] = $this->config['ssl_cert'];
+                }
+                if ($this->config['ssl_ca']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CA] = $this->config['ssl_ca'];
+                }
+                if ($this->config['ssl_capath']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CAPATH] = $this->config['ssl_capath'];
+                }
+                if ($this->config['ssl_cipher']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
+                }
+            }
             $this->zendConn = new Zend_Db_Adapter_Pdo_Mysql($config);
         } elseif ($this->config['db'] === 'pgsql') {
             $this->zendConn = new Zend_Db_Adapter_Pdo_Pgsql($config);
@@ -280,17 +299,44 @@ class DbTool
      *
      * @param   string  $dbname     The name of the database to connect with
      */
-    protected function _pdoConnect($dbname)
+    private function pdoConnect($dbname)
     {
         if ($this->pdoConn !== null) {
             return;
         }
 
+        $driverOptions = array(
+            PDO::ATTR_TIMEOUT => 1,
+            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
+        );
+
+        if ($this->config['db'] === 'mysql'
+            && isset($this->config['use_ssl'])
+            && $this->config['use_ssl']
+        ) {
+            # The presence of these keys as empty strings or null cause non-ssl connections to fail
+            if ($this->config['ssl_key']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_KEY] = $this->config['ssl_key'];
+            }
+            if ($this->config['ssl_cert']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CERT] = $this->config['ssl_cert'];
+            }
+            if ($this->config['ssl_ca']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CA] = $this->config['ssl_ca'];
+            }
+            if ($this->config['ssl_capath']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CAPATH] = $this->config['ssl_capath'];
+            }
+            if ($this->config['ssl_cipher']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
+            }
+        }
+
         $this->pdoConn = new PDO(
             $this->buildDsn($this->config['db'], $dbname),
             $this->config['username'],
             $this->config['password'],
-            array(PDO::ATTR_TIMEOUT => 1, PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
+            $driverOptions
         );
     }
 
@@ -332,7 +378,12 @@ class DbTool
         } catch (PDOException $e) {
             if ($this->config['db'] === 'mysql') {
                 $code = $e->getCode();
-                if ($code !== 1040 && $code !== 1045) {
+                /*
+                 * 1040 .. Too many connections
+                 * 1045 .. Access denied for user '%s'@'%s' (using password: %s)
+                 * 1698 .. Access denied for user '%s'@'%s'
+                 */
+                if ($code !== 1040 && $code !== 1045 && $code !== 1698) {
                     throw $e;
                 }
             } elseif ($this->config['db'] === 'pgsql') {
@@ -536,7 +587,7 @@ class DbTool
             $to = sprintf(
                 ' TO %s@%s',
                 $this->quoteIdentifier($username),
-                str_replace('%', '%%', $this->quoteIdentifier($host))
+                $this->quoteIdentifier($host)
             );
 
             $dbPrivileges = array();
