@@ -1,6 +1,6 @@
 /*! Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
-// @TODO(el): https://dev.icinga.org/issues/10646
+// @TODO(el): https://dev.icinga.com/issues/10646
 (function(Icinga, $) {
 
     'use strict';
@@ -10,6 +10,7 @@
     var ApplicationState = function (icinga) {
         Icinga.EventListener.call(this, icinga);
         this.on('rendered', this.onRendered, this);
+        this.on('rendered', '#application-state-summary', this.onSummaryRendered, this);
         this.icinga = icinga;
     };
 
@@ -31,6 +32,13 @@
         }
     };
 
+    ApplicationState.prototype.onSummaryRendered = function(e) {
+        var height = $(this).height();
+
+        $('#sidebar').css('bottom', height);
+        $('#main').css('bottom', height);
+    };
+
     Icinga.Behaviors.ApplicationState = ApplicationState;
 
 })(Icinga, jQuery);
